pub struct VerifyingKey(/* private fields */);Expand description
Ed448 verifying key (RFC 8032).
Implementations
Sourceimpl VerifyingKey
impl VerifyingKey
Sourcepub fn from_bytes(bytes: &[u8; 57]) -> Result<Self>
pub fn from_bytes(bytes: &[u8; 57]) -> Result<Self>
Parse a verifying key from 57 bytes.
Sourcepub fn verify(&self, message: &[u8], signature: &Signature) -> Result<()>
pub fn verify(&self, message: &[u8], signature: &Signature) -> Result<()>
Verify a 114-byte signature over a message.
Returns Ok(()) if the signature is valid, or an error otherwise.
The argument order is verify(message, signature) to match the
convention used by the hybrid constructions in this SDK.